==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-drools/drools-core/src/test/java/org/drools/core/time/impl/CronJobTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.drools.core.time.impl;

import java.util.concurrent.TimeUnit;

import org.drools.core.ClockType;
import org.drools.core.SessionConfiguration;
import org.drools.core.impl.RuleBaseFactory;
import org.drools.core.time.impl.JDKTimerServiceTest.HelloWorldJob;
import org.drools.core.time.impl.JDKTimerServiceTest.HelloWorldJobContext;
import org.junit.Test;

import static org.assertj.core.api.Assertions.assertThat;

public class CronJobTest {
    @Test
    public void testCronTriggerJob() throws Exception {
        SessionConfiguration config = RuleBaseFactory.newKnowledgeSessionConfiguration().as(SessionConfiguration.KEY);
        config.setClockType(ClockType.PSEUDO_CLOCK);
        PseudoClockScheduler timeService = (PseudoClockScheduler) config.createTimerService();

        timeService.advanceTime( 0,
                                 TimeUnit.MILLISECONDS );

        CronTrigger trigger = new CronTrigger( 0,
                                               null,
                                               null,
                                               -1,
                                               "15 * * * * ?",
                                               null,
                                               null );

        HelloWorldJobContext ctx = new HelloWorldJobContext( "hello world",
                                                             timeService );
        timeService.scheduleJob( new HelloWorldJob(),
                                 ctx,
                                 trigger );

        assertThat(ctx.getList()).hasSize(0);

        timeService.advanceTime( 10,
                                 TimeUnit.SECONDS );
        assertThat(ctx.getList()).hasSize(0);

        timeService.advanceTime( 10,
                                 TimeUnit.SECONDS );
        assertThat(ctx.getList()).hasSize(1);

        timeService.advanceTime( 30,
                                 TimeUnit.SECONDS );
        assertThat(ctx.getList()).hasSize(1);

        timeService.advanceTime( 30,
                                 TimeUnit.SECONDS );
        assertThat(ctx.getList()).hasSize(2);
    }
}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-drools/drools-core/src/test/java/org/drools/core/time/impl/CronJobTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.drools.core.time.impl;

import java.util.concurrent.TimeUnit;

import org.drools.core.ClockType;
import org.drools.core.SessionConfiguration;
import org.drools.core.impl.RuleBaseFactory;
import org.drools.core.time.impl.JDKTimerServiceTest.HelloWorldJob;
import org.drools.core.time.impl.JDKTimerServiceTest.HelloWorldJobContext;
import org.junit.jupiter.api.Test;

import static org.assertj.core.api.Assertions.assertThat;

public class CronJobTest {
	
    @Test
    public void testCronTriggerJob() throws Exception {
        SessionConfiguration config = RuleBaseFactory.newKnowledgeSessionConfiguration().as(SessionConfiguration.KEY);
        config.setClockType(ClockType.PSEUDO_CLOCK);
        PseudoClockScheduler timeService = (PseudoClockScheduler) config.createTimerService();

        timeService.advanceTime( 0,
                                 TimeUnit.MILLISECONDS );

        CronTrigger trigger = new CronTrigger( 0,
                                               null,
                                               null,
                                               -1,
                                               "15 * * * * ?",
                                               null,
                                               null );

        HelloWorldJobContext ctx = new HelloWorldJobContext( "hello world",
                                                             timeService );
        timeService.scheduleJob( new HelloWorldJob(),
                                 ctx,
                                 trigger );

        assertThat(ctx.getList()).hasSize(0);

        timeService.advanceTime( 10,
                                 TimeUnit.SECONDS );
        assertThat(ctx.getList()).hasSize(0);

        timeService.advanceTime( 10,
                                 TimeUnit.SECONDS );
        assertThat(ctx.getList()).hasSize(1);

        timeService.advanceTime( 30,
                                 TimeUnit.SECONDS );
        assertThat(ctx.getList()).hasSize(1);

        timeService.advanceTime( 30,
                                 TimeUnit.SECONDS );
        assertThat(ctx.getList()).hasSize(2);
    }
}
